<!--
SPDX-FileCopyrightText: 2025 Stefano Miccoli <stefano.miccoli@polimi.it>

SPDX-License-Identifier: MIT
-->

# `suanpan-abaqus` package

Python interface to Abaqus `.fil` files

## Name

The suànpán ([算盤](https://en.wiktionary.org/wiki/算盤)) is the [chinese abacus](https://en.wikipedia.org/wiki/Suanpan).

## License

This package is released under the MIT License.

© 2025 Stefano Miccoli
